translate.storage.proj

Package translate :: Package storage :: Module proj |
[hide private]
[frames] | no frames]

# Source Code for Module translate.storage.proj

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2010 Zuza Software Foundation
     5  #
     6  # This file is part of the Translate Toolkit.
     7  #
     8  # This program is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # This program is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with this program; if not, see <http://www.gnu.org/licenses/>.
    20
    21  """Serves as single import for all project-related classes."""
    22
    23  from project import Project, split_extensions
    24  from projstore import ProjectStore, FileExistsInProjectError, FileNotInProjectError
    25  from bundleprojstore import BundleProjectStore, InvalidBundleError
    26
    27  __all__ = [
    28      # Classes
    29      'Project', 'ProjectStore', 'BundleProjectStore',
    30      # Exceptions
    31      'FileExistsInProjectError', 'FileNotInProjectError', 'InvalidBundleError',
    32      # Functions
    33      'split_extensions',
    34  ]
    35